import * as vueRouter from 'vue-router'
import baseData from "./modules/base";
import config from '~src/config/index'
import authStore from '~src/api/util/auth'
import {getRouterData} from './routers'
import {isItem} from "vue-utils-plus"
import NProgress from "nprogress";
import "~src/styles/app/nprogress.scss";

//设置路由数据
const router = vueRouter.createRouter({
    history: vueRouter.createWebHashHistory(),
    routes: baseData
});

//路由拦截
router.beforeEach(async (to, from, next) => {
    NProgress.start();
    const token = authStore.getToken()
    if (to.path === '/login') {
        next()
    } else if (!token) {
        next('/login')
    } else {
        const {routes} = await getRouterData()
        if (isItem(routes, to.name)) {
            next()
        } else {
            next('/404')
        }
    }
})

router.afterEach((to) => {
    //根据当前跳转的路由设置显示在浏览器标签的title
    let pageTitle = to.meta['title'], title = config.title;
    if (to.path !== "/") {
        window.document.title =  pageTitle?`${pageTitle} - ${title}`:title;
    } else {
        window.document.title = title;
    }
    window.scrollTo(0, 0)
    NProgress.done();
})

export function setupRouter(app){
    app.use(router)
    return router
}

export default router;
