import pinia from "~src/store/init"
import appConfig from '~src/config/app';
import {useAppStore} from "~src/store/index";
import {userLogin,refreshToken,logout} from '~api/user';
import {userConfigInfo, userConfigSave} from "~api/other";
import themeData from '~src/config/theme';
import {getIndex, getObjValue} from "vue-utils-plus"
import {useOsTheme} from 'vooks'

const store = useAppStore(pinia)

//登录
export const useAppLogin = async (form) => {
    try {
        const { error, status, res } = await userLogin(form);
        if (!error && status === 200) {
            store.setToken(res['access_token'])
            store.setRefreshToken(res['refresh_token'])
            store.setTenantId(res['tenant_id'])
            store.setUserInfo(res)
            await initUserConfigInfo()
            return Promise.resolve(res);
        } else {
            return Promise.reject(res);
        }
    } catch (e) {
        window.console.warn('token 刷新失败: ', e);
        return Promise.reject(e);
    }
}

//用户信息初始化
export const initUserConfigInfo = async () => {
    const {error, data} = await userConfigInfo();
    if (error) return true
    const res = getObjValue(data)
    if (res?.theme) {
        const {theme,color,homeTheme,shotWebRtc,fullScreen,opinionView} = res
        //设置主题
        store.setTheme(theme)
        //设置模式
        if (theme === 'auto') {
            store.setThemeVal(useOsTheme().value)
        } else {
            store.setThemeVal(theme)
        }
        //获取主色调和首页主题数据
        let themeColor = themeData.color, themeHome = themeData.home;
        let colorIndex = getIndex(themeColor,'name',color)
        let homeIndex = getIndex(themeHome,'name',homeTheme)
        //设置主色调
        if (colorIndex !== -1) {
            store.setColor(themeColor[colorIndex])
        }
        //设置首页主题
        if (homeIndex !== -1) {
            store.setHomeTheme(themeHome[homeIndex])
        }
        //设置工单服务的弹出框
        store.setOrderServiceTipModal(opinionView ?? 1)
        store.setShotWebRtc(shotWebRtc)
        store.setShotWebRtc(fullScreen)
        return true
    } else {
        await userConfigSave({
            theme: appConfig?.theme || '',
            color: appConfig?.color?.name || '',
            homeTheme: appConfig?.homeTheme?.name || '',
            shotWebRtc: '0',
            fullScreen: '1',
            opinionView: 1
        })
        return true
    }
}

//刷新token
export const RefreshToken = async () => {
    try {
        window.console.log('刷新 token');
        const { dept_id, role_id } = store.getUserInfo;
        const refresh = store.getRefreshToken;
        const tenantId = store.getTenantId;
        const { error, status, res } = await refreshToken(refresh, tenantId, dept_id, role_id);
        if (!error && status === 200) {
            store.setToken(res['access_token'])
            store.setRefreshToken(res['refresh_token'])
            store.setTenantId(res['tenant_id'])
            store.setUserInfo(res)
            return Promise.resolve(res);
        } else {
            return Promise.reject(res);
        }
    } catch (e) {
        window.console.warn('token 刷新失败: ', e);
        return Promise.reject(e);
    }
}

//登出
export const LogOut = async () => {
    await logout();
    return Promise.resolve(true);
}
